@@ -51,7 +51,7 @@ class Base(ABC):
                     },
                     "meta": {
                         "id_transaction": original["metadata"]["id_transaction"],
-                        "status": 'ERROR' if errorCode < 0 else 'SUCCESS'
+                        "status": 'ERROR' if errorCode < 0 or errorCode > 0 else 'SUCCESS'
                     }
                 },
                 "uuid": original.get("uuid", None),
